@@ -1,3 +1,4 @@
+__version__ = '0.2.9'
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
@@ -25,13 +26,15 @@ __FUZZY_ROTATION = "fuzzy_rotation"
 __SUPPRESS_PRINT = "suppress_print"
 
 __TOOL_DESCRIPTION = """\
+version {0}
 Listens to a log file and transfers the appended data to SlickLog.com.
 The tool can take the SlickLog configuration from the command line
 or from a configuration file.
 Usage examples:
- {0} --{1} WlHfkJOgIEnSX3tD --{2} 'My Log Group' --{3} 'My Log' /logs/mylog.log
- {4} --{5} /conf/slicklog.cofig /logs/mylog.log
-""".format(__TOOL_NAME, __SLICKLOG_API_KEY, __SLICKLOG_LOG_GROUP_NAME, __SLICKLOG_LOG_NAME,
+ {1} --{2} WlHfkJOgIEnSX3tD --{3} 'My Log Group' --{5} 'My Log' /logs/mylog.log
+ {5} --{6} /conf/slicklog.cofig /logs/mylog.log
+""".format(__version__,
+           __TOOL_NAME, __SLICKLOG_API_KEY, __SLICKLOG_LOG_GROUP_NAME, __SLICKLOG_LOG_NAME,
            __TOOL_NAME, __CONFIG_FILE)
 
 __CONFIG_FILE_DESCRIPTION = """\
@@ -53,34 +56,34 @@ This is an example:
     __SLICKLOG_LOG_NAME)
 
 
-def _check_option_exists(config, filename, section, option):
-  if not config.has_option(section, option):
-    print("No option {0} in section [{1}] in config file {2}.".format(
-          option, section, filename))
-    exit(0)
-
-
 def _check_config_file(config, filename):
   if not config.has_section(__SLICKLOG):
     print("No section [{0}[ in config file {1}.".format(__SLICKLOG, filename))
     exit(0)
-  _check_option_exists(config, filename, __SLICKLOG, __SLICKLOG_API_KEY)
-  _check_option_exists(config, filename, __SLICKLOG, __SLICKLOG_LOG_GROUP_NAME)
-  _check_option_exists(config, filename, __SLICKLOG, __SLICKLOG_LOG_NAME)
+
+
+def _get_option(config, section, option):
+  if not config.has_option(section, option):
+    return None
+  return config.get(section, option)
 
 
 def _read_config_file(filename):
+  if filename is None:
+    return None, None, None, None
+  if not os.path.isfile(filename):
+    print('The configuration file {0} does not exist.'.format(filename))
+    exit(0)
+
   config = ConfigParser.RawConfigParser()
   config.read(filename)
 
   _check_config_file(config, filename)
 
-  api_key = config.get(__SLICKLOG, __SLICKLOG_API_KEY)
-  log_group_name = config.get(__SLICKLOG, __SLICKLOG_LOG_GROUP_NAME)
-  log_name = config.get(__SLICKLOG, __SLICKLOG_LOG_NAME)
-  endpoint = None
-  if config.has_option(__SLICKLOG, __SLICKLOG_ENDPOINT):
-    endpoint = config.get(__SLICKLOG, __SLICKLOG_ENDPOINT)
+  api_key = _get_option(config, __SLICKLOG, __SLICKLOG_API_KEY)
+  log_group_name = _get_option(config, __SLICKLOG, __SLICKLOG_LOG_GROUP_NAME)
+  log_name = _get_option(config, __SLICKLOG, __SLICKLOG_LOG_NAME)
+  endpoint = _get_option(config, __SLICKLOG, __SLICKLOG_ENDPOINT)
 
   return api_key, log_group_name, log_name, endpoint
 
@@ -91,16 +94,18 @@ def _check_not_none(prop, val):
     exit(0)
 
 
+def _nvl(a1, a2):
+  if a1 is None:
+    return a2
+  return a1
+
+
 def _get_config(args):
-  if args.config_file is not None:
-    if not os.path.isfile(args.config_file):
-      print('The configuration file {0} does not exist.'.format(args.config_file))
-      exit(0)
-    return _read_config_file(args.config_file)
-  api_key = args.api_key
-  log_group_name = args.log_group_name
-  log_name = args.log_name
-  endpoint = args.endpoint
+  api_key, log_group_name, log_name, endpoint = _read_config_file(args.config_file)
+  api_key = _nvl(args.api_key, api_key)
+  log_group_name = _nvl(args.log_group_name, log_group_name)
+  log_name = _nvl(args.log_name, log_name)
+  endpoint = _nvl(args.endpoint, endpoint)
 
   _check_not_none(__SLICKLOG_API_KEY, api_key)
   _check_not_none(__SLICKLOG_LOG_GROUP_NAME, log_group_name)
@@ -132,6 +137,7 @@ def main():
   api_key, log_group_name, log_name, endpoint = _get_config(args)
 
   print(' -- Running on Configuration --')
+  print '  {0} => {1}'.format('version', __version__)
   print('  {0} => {1}'.format(__LOGFILE, args.logfile))
   print('  {0} => {1}'.format(__SLICKLOG_LOG_GROUP_NAME, log_group_name))
   print('  {0} => {1}'.format(__SLICKLOG_LOG_NAME, log_name))
